@@ -1,11 +1,12 @@
 __version_info__ = {
-    'major': 0,
-    'minor': 2,
-    'micro': 2,
+    'major': 1,
+    'minor': 0,
+    'micro': 0,
     'releaselevel': 'final',
-    'serial': 1
+    'serial': 4
 }
 
+
 def get_version():
     vers = ["%(major)i.%(minor)i" % __version_info__, ]
 
@@ -19,5 +20,5 @@ __version__ = get_version()
 
 try:
     from modules import get_memcache_dash_modules, get_rss_dash_modules, get_varnish_dash_modules
-except ImportError:
+except Exception:
     pass
